# Input-Tools

This package can be used to simulate any sort of input event

## Usage

This is an example of simulating a left mouse click-

left_click_mouse()

Note- This package only works with Python 3
